@@ -1,5 +1,4 @@
 import pathlib
-import sys
 import tempfile
 from typing import Optional, Sequence
 
@@ -10,6 +9,7 @@ import yaml
 
 from ..cli_constants import CONFIGURATION_PATH, DEFAULT_GLOBAL_CONFIG
 from ..data_structures import DataPipelinesConfig
+from ..errors import DataPipelinesError
 
 
 def _download_global_config(config_path: str) -> DataPipelinesConfig:
@@ -21,13 +21,20 @@ def _download_global_config(config_path: str) -> DataPipelinesConfig:
 
 
 def init(config_path: Optional[str]) -> None:
+    """
+    Configure the tool for the first time
+
+    :param config_path: URI of the repository with a template of the config file
+    :type config_path: Optional[str]
+    :raises DataPipelinesError: user do not want to overwrite existing config file
+    """
     if CONFIGURATION_PATH.is_file():
         overwrite_confirm = questionary.confirm(
             "dp config already exists. Do you want to overwrite it?",
             default=False,
         ).ask()
         if not overwrite_confirm:
-            sys.exit(1)
+            raise DataPipelinesError("Could not overwrite existing config")
 
     if config_path:
         config = _download_global_config(config_path)
@@ -38,7 +45,7 @@ def init(config_path: Optional[str]) -> None:
         yaml.dump(config, f, default_flow_style=False)
 
 
-@click.command(name="init")
+@click.command(name="init", help="Configure the tool for the first time")
 @click.argument("config_path", nargs=-1)
 def init_command(config_path: Sequence[str]) -> None:
     init(config_path[0] if config_path else None)
